@@ -382,7 +382,7 @@ def create_unittests(checks):
 
 #-------------------------------------------------------------------------------
 def search_in_all_levels(filename):
-    for level in ['manuallevel', 'level0', 'level1', 'level2', 'level3']:
+    for level in ['manuallevel', 'level0', 'level1', 'level2']:
         complete_filename = clazy_source_path() + 'src/checks/' + level + '/' + filename
         if os.path.exists(complete_filename):
             return complete_filename
@@ -391,8 +391,9 @@ def search_in_all_levels(filename):
 #-------------------------------------------------------------------------------
 def create_checks(checks):
     generated = False
-    edit_changelog = False
+
     for check in checks:
+        edit_changelog = False
         include_file = check.path() + check.include()
         cpp_file = check.path() + check.cpp_filename()
         copyright = get_copyright()
@@ -451,7 +452,7 @@ def generate_readme(checks):
     f.close();
 
     new_text_to_insert = ""
-    for level in ['-1', '0', '1', '2', '3']:
+    for level in ['-1', '0', '1', '2']:
         new_text_to_insert += "- Checks from %s:" % level_num_to_name(int(level)) + "\n"
         for c in checks:
             if str(c.level) == level:
@@ -498,7 +499,7 @@ def generate_readmes_cmake_install(checks):
         f.close();
 
     new_text_to_insert = ""
-    for level in ['-1', '0', '1', '2', '3']:
+    for level in ['-1', '0', '1', '2']:
         new_text_to_insert += 'SET(' + level_num_to_cmake_readme_variable(int(level)) + "\n"
         for c in checks:
             if str(c.level) == level:
