@@ -103,7 +103,8 @@ public:
         const bool isSlot = (isSlots || isSignals) ? false : name == "Q_SLOT";
         const bool isSignal = (isSlots || isSignals || isSlot) ? false : name == "Q_SIGNAL";
         const bool isInvokable = (isSlots || isSignals || isSlot || isSignal) ? false : name == "Q_INVOKABLE";
-        if (!isSlots && !isSignals && !isSlot && !isSignal & !isInvokable)
+        const bool isScriptable = (isSlot || isSignal || isInvokable) ? false : name == "Q_SCRIPTABLE";
+        if (!isSlots && !isSignals && !isSlot && !isSignal && !isInvokable && !isScriptable)
             return;
 
         SourceLocation loc = range.getBegin();
@@ -124,14 +125,17 @@ public:
             } else if (isSlot) {
                 m_individualSlots.push_back(loc.getRawEncoding());
             } else if (isInvokable) {
-                m_individualInvokables.push_back(loc.getRawEncoding());
+                m_invokables.push_back(loc.getRawEncoding());
+            } else if (isScriptable) {
+                m_scriptables.push_back(loc.getRawEncoding());
             }
         }
     }
 
     vector<unsigned> m_individualSignals; // Q_SIGNAL
     vector<unsigned> m_individualSlots;   // Q_SLOT
-    vector<unsigned> m_individualInvokables; // Q_INVOKABLE
+    vector<unsigned> m_invokables; // Q_INVOKABLE
+    vector<unsigned> m_scriptables; // Q_SCRIPTABLE
     const CompilerInstance &m_ci;
     ClazySpecifierList m_qtAccessSpecifiers;
 };
@@ -220,7 +224,7 @@ QtAccessSpecifierType AccessSpecifierManager::qtAccessSpecifierType(const CXXMet
     }
 
     // Process Q_INVOKABLE:
-    for (auto loc : m_preprocessorCallbacks->m_individualInvokables) {
+    for (auto loc : m_preprocessorCallbacks->m_invokables) {
         if (loc == methodLoc.getRawEncoding())
             return QtAccessSpecifier_Invokable;
     }
@@ -249,6 +253,23 @@ QtAccessSpecifierType AccessSpecifierManager::qtAccessSpecifierType(const CXXMet
     return (*i).qtAccessSpecifier;
 }
 
+bool AccessSpecifierManager::isScriptable(const CXXMethodDecl *method) const
+{
+    if (!method)
+        return false;
+
+    const SourceLocation methodLoc = clazy::getLocStart(method);
+     if (methodLoc.isMacroID())
+         return false;
+
+    for (auto loc : m_preprocessorCallbacks->m_scriptables) {
+        if (loc == methodLoc.getRawEncoding())
+            return true;
+    }
+
+    return false;
+}
+
 llvm::StringRef AccessSpecifierManager::qtAccessSpecifierTypeStr(QtAccessSpecifierType t) const
 {
     switch (t) {
@@ -261,7 +282,7 @@ llvm::StringRef AccessSpecifierManager::qtAccessSpecifierTypeStr(QtAccessSpecifi
         return "signal";
     case QtAccessSpecifier_Invokable:
         return "invokable";
-    default:
-        return "";
     }
+
+    return "";
 }
