@@ -87,6 +87,11 @@ public:
      */
     QtAccessSpecifierType qtAccessSpecifierType(const clang::CXXMethodDecl*) const;
 
+    /**
+     * Returns if a method is scriptable (Q_SCRIPTABLE)
+     */
+    bool isScriptable(const clang::CXXMethodDecl*) const;
+
     /**
      * Returns a string representations of a Qt Access Specifier Type
      */
