@@ -20,13 +20,14 @@
 */
 
 #include "AccessSpecifierManager.h"
-#include "PreProcessorVisitor.h"
 #include "ClazyContext.h"
+#include "FixItExporter.h"
+#include "PreProcessorVisitor.h"
 
 #include <clang/AST/ParentMap.h>
-#include <clang/Rewrite/Frontend/FixItRewriter.h>
 #include <clang/Frontend/CompilerInstance.h>
 #include <clang/Lex/PreprocessorOptions.h>
+#include <clang/Rewrite/Frontend/FixItRewriter.h>
 #include <llvm/Support/Regex.h>
 
 #include <stdlib.h>
@@ -34,40 +35,18 @@
 using namespace std;
 using namespace clang;
 
-class ClazyFixItOptions
-    : public FixItOptions
-{
-public:
-    ClazyFixItOptions(const ClazyFixItOptions &other) = delete;
-    ClazyFixItOptions(bool inplace)
-    {
-        if (const char *suffix = getenv("CLAZY_FIXIT_SUFFIX"))
-            m_suffix = suffix;
-
-        InPlace = inplace && m_suffix.empty();
-        FixWhatYouCan = true;
-        FixOnlyWarnings = true;
-        Silent = false;
-    }
-
-    std::string RewriteFilename(const std::string &filename, int &fd) override
-    {
-        fd = -1;
-        return InPlace ? filename
-                       : filename + m_suffix;
-    }
-
-    std::string m_suffix;
-};
 
 ClazyContext::ClazyContext(const clang::CompilerInstance &compiler,
-                           const string &headerFilter, const string &ignoreDirs, ClazyOptions opts)
+                           const string &headerFilter, const string &ignoreDirs,
+                           string exportFixesFilename,
+                           const std::vector<string> &translationUnitPaths, ClazyOptions opts)
     : ci(compiler)
     , astContext(ci.getASTContext())
     , sm(ci.getSourceManager())
     , m_noWerror(getenv("CLAZY_NO_WERROR") != nullptr) // Allows user to make clazy ignore -Werror
     , options(opts)
     , extraOptions(clazy::splitString(getenv("CLAZY_EXTRA_OPTIONS"), ','))
+    , m_translationUnitPaths(translationUnitPaths)
 {
     if (!headerFilter.empty())
         headerFilterRegex = std::unique_ptr<llvm::Regex>(new llvm::Regex(headerFilter));
@@ -75,20 +54,18 @@ ClazyContext::ClazyContext(const clang::CompilerInstance &compiler,
     if (!ignoreDirs.empty())
         ignoreDirsRegex = std::unique_ptr<llvm::Regex>(new llvm::Regex(ignoreDirs));
 
-    const char *fixitsEnv = getenv("CLAZY_FIXIT");
-    allFixitsEnabled = (options & ClazyOption_AllFixitsEnabled);
-    if (!allFixitsEnabled && fixitsEnv) {
-        const string fixitsEnvStr = clazy::unquoteString(fixitsEnv);
-        if (fixitsEnvStr == "all_fixits") {
-            allFixitsEnabled = true;
-        } else {
-            requestedFixitName = fixitsEnvStr;
+    if (exportFixesEnabled()) {
+        if (exportFixesFilename.empty()) {
+            // Only clazy-standalone sets the filename by argument.
+            // clazy plugin sets it automatically here:
+            const FileEntry *fileEntry = sm.getFileEntryForID(sm.getMainFileID());
+            exportFixesFilename = fileEntry->getName().str() + ".clazy.yaml";
         }
-    }
 
-    if (fixitsEnabled() && !(options & ClazyOption_NoFixitsAutoWrite))
-        rewriter = new FixItRewriter(ci.getDiagnostics(), sm,
-                                     ci.getLangOpts(), new ClazyFixItOptions(fixitsAreInplace()));
+        const bool isClazyStandalone = !translationUnitPaths.empty();
+        exporter = new FixItExporter(ci.getDiagnostics(), sm, ci.getLangOpts(),
+                                     exportFixesFilename, isClazyStandalone);
+    }
 }
 
 ClazyContext::~ClazyContext()
@@ -97,9 +74,17 @@ ClazyContext::~ClazyContext()
     delete accessSpecifierManager;
     delete parentMap;
 
-    if (rewriter) {
-        rewriter->WriteFixedFiles();
-        delete rewriter;
+    static unsigned long count = 0;
+    count++;
+
+    if (exporter) {
+        // With clazy-standalone we use the same YAML file for all translation-units, so only
+        // write out the last one. With clazy-plugin there's a YAML file per translation unit.
+        const bool isClazyPlugin = m_translationUnitPaths.empty();
+        const bool isLast = count == m_translationUnitPaths.size();
+        if (isLast || isClazyPlugin)
+            exporter->Export();
+        delete exporter;
     }
 
     preprocessorVisitor = nullptr;
@@ -119,15 +104,27 @@ void ClazyContext::enablePreprocessorVisitor()
         preprocessorVisitor = new PreProcessorVisitor(ci);
 }
 
+void ClazyContext::enableVisitallTypeDefs()
+{
+    // By default we only process decls from the .cpp file we're processing, not stuff included (for performance)
+    /// But we might need to process all typedefs, not only the ones in our current .cpp files
+    m_visitsAllTypeDefs = true;
+}
+
+bool ClazyContext::visitsAllTypedefs() const
+{
+    return m_visitsAllTypeDefs;
+}
+
 bool ClazyContext::isQt() const
 {
     static const bool s_isQt = [this] {
-        for (auto s : ci.getPreprocessorOpts().Macros) {
-            if (s.first == "QT_CORE_LIB")
-                return true;
-        }
-        return false;
-    } ();
+                                   for (auto s : ci.getPreprocessorOpts().Macros) {
+                                       if (s.first == "QT_CORE_LIB")
+                                           return true;
+                                   }
+                                   return false;
+                               } ();
 
     return s_isQt;
 }
