@@ -45,34 +45,33 @@ class CompilerInstance;
 class ASTContext;
 class ParentMap;
 class SourceManager;
-class FixItRewriter;
 class CXXMethodDecl;
 class Decl;
 }
 
 class AccessSpecifierManager;
 class PreProcessorVisitor;
+class FixItExporter;
 
 class ClazyContext
 {
 public:
-
     enum ClazyOption {
         ClazyOption_None = 0,
-        ClazyOption_NoFixitsInplace = 1,
-        ClazyOption_NoFixitsAutoWrite = 2, // If enabled then fixits are reported, but not applied
-        ClazyOption_AllFixitsEnabled = 4,
-        ClazyOption_Qt4Compat = 8,
-        ClazyOption_OnlyQt = 16, // Ignore non-Qt files. This is done by bailing out if QT_CORE_LIB is not set.
-        ClazyOption_QtDeveloper = 32, // For running clazy on Qt itself, optional, but honours specific guidelines
-        ClazyOption_VisitImplicitCode = 64, // Inspect compiler generated code aswell, useful for custom checks, if they need it
-        ClazyOption_IgnoreIncludedFiles = 128 // Only warn for the current file being compiled, not on includes (useful for performance reasons)
+        ClazyOption_ExportFixes = 1,
+        ClazyOption_Qt4Compat = 2,
+        ClazyOption_OnlyQt = 4, // Ignore non-Qt files. This is done by bailing out if QT_CORE_LIB is not set.
+        ClazyOption_QtDeveloper = 8, // For running clazy on Qt itself, optional, but honours specific guidelines
+        ClazyOption_VisitImplicitCode = 16, // Inspect compiler generated code aswell, useful for custom checks, if they need it
+        ClazyOption_IgnoreIncludedFiles = 32 // Only warn for the current file being compiled, not on includes (useful for performance reasons)
     };
     typedef int ClazyOptions;
 
     explicit ClazyContext(const clang::CompilerInstance &ci,
                           const std::string &headerFilter,
                           const std::string &ignoreDirs,
+                          std::string exportFixesFilename,
+                          const std::vector<std::string> &translationUnitPaths,
                           ClazyOptions = ClazyOption_None);
     ~ClazyContext();
 
@@ -86,14 +85,9 @@ public:
         return m_noWerror;
     }
 
-    bool fixitsAreInplace() const
+    bool exportFixesEnabled() const
     {
-        return !(options & ClazyOption_NoFixitsInplace);
-    }
-
-    bool fixitsEnabled() const
-    {
-        return allFixitsEnabled || !requestedFixitName.empty();
+        return options & ClazyOption_ExportFixes;
     }
 
     bool isQtDeveloper() const
@@ -167,6 +161,9 @@ public:
      */
     void enableAccessSpecifierManager();
     void enablePreprocessorVisitor();
+    void enableVisitallTypeDefs();
+    bool visitsAllTypedefs() const;
+
     bool isQt() const;
 
     // TODO: More things will follow
@@ -177,16 +174,17 @@ public:
     PreProcessorVisitor *preprocessorVisitor = nullptr;
     SuppressionManager suppressionManager;
     const bool m_noWerror;
+    bool m_visitsAllTypeDefs = false;
     clang::ParentMap *parentMap = nullptr;
     const ClazyOptions options;
     const std::vector<std::string> extraOptions;
-    clang::FixItRewriter *rewriter = nullptr;
-    bool allFixitsEnabled = false;
-    std::string requestedFixitName;
+    FixItExporter *exporter = nullptr;
     clang::CXXMethodDecl *lastMethodDecl = nullptr;
+    clang::FunctionDecl *lastFunctionDecl = nullptr;
     clang::Decl *lastDecl = nullptr;
     std::unique_ptr<llvm::Regex> headerFilterRegex;
     std::unique_ptr<llvm::Regex> ignoreDirsRegex;
+    const std::vector<std::string> m_translationUnitPaths;
 };
 
 #endif
