@@ -186,7 +186,7 @@ bool isJavaIterator(clang::CXXMemberCallExpr *call);
  */
 inline bool isTooBigForQList(clang::QualType qt, const clang::ASTContext *context)
 {
-    return (int)context->getTypeSize(qt) <= TypeUtils::sizeOfPointer(context, qt);
+    return (int)context->getTypeSize(qt) <= clazy::sizeOfPointer(context, qt);
 }
 
 /**
@@ -197,18 +197,6 @@ inline bool isTooBigForQList(clang::QualType qt, const clang::ASTContext *contex
  */
 bool recordHasCtorWithParam(clang::CXXRecordDecl *record, const std::string &paramType, bool &ok, int &numCtors);
 
-/**
- * Returns true if we can prove the container doesn't detach.
- * Returns false otherwise, meaning that you can't conclude anything if false is returned.
- *
- * For true to be returned, all these conditions must verify:
- * - Container is a local variable
- * - It's not passed to any function
- * - It's not assigned to another variable
- */
-bool containerNeverDetaches(const clang::VarDecl *varDecl,
-                            StmtBodyRange bodyRange);
-
 /**
  * Returns true if recordDecl is one of the container classes that supports reserve(), such
  * as QList, QVector, etc.
@@ -295,7 +283,7 @@ inline bool is_qobject_cast(clang::Stmt *s, clang::CXXRecordDecl **castTo = null
                     expr = implicitCast->getSubExpr();
                 }
             }
-            clang::QualType qt = TypeUtils::pointeeQualType(expr->getType());
+            clang::QualType qt = clazy::pointeeQualType(expr->getType());
             if (!qt.isNull()) {
                 clang::CXXRecordDecl *record = qt->getAsCXXRecordDecl();
                 *castFrom = record ? record->getCanonicalDecl() : nullptr;
@@ -306,7 +294,7 @@ inline bool is_qobject_cast(clang::Stmt *s, clang::CXXRecordDecl **castTo = null
             auto templateArgs = func->getTemplateSpecializationArgs();
             if (templateArgs->size() == 1) {
                 const clang::TemplateArgument &arg = templateArgs->get(0);
-                clang::QualType qt = TypeUtils::pointeeQualType(arg.getAsType());
+                clang::QualType qt = clazy::pointeeQualType(arg.getAsType());
                 if (!qt.isNull()) {
                     clang::CXXRecordDecl *record = qt->getAsCXXRecordDecl();
                     *castTo = record ? record->getCanonicalDecl() : nullptr;
