@@ -1,47 +1,60 @@
 /*
-   This file is part of the clazy static checker.
+    This file is part of the clazy static checker.
 
-  Copyright (C) 2015 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
-  Author: Sérgio Martins <sergio.martins@kdab.com>
+    Copyright (C) 2015 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
+    Author: Sérgio Martins <sergio.martins@kdab.com>
 
-  Copyright (C) 2015-2016 Sergio Martins <smartins@kde.org>
+    Copyright (C) 2015-2016 Sergio Martins <smartins@kde.org>
 
-  This library is free software; you can redistribute it and/or
-  modify it under the terms of the GNU Library General Public
-  License as published by the Free Software Foundation; either
-  version 2 of the License, or (at your option) any later version.
+    This library is free software; you can redistribute it and/or
+    modify it under the terms of the GNU Library General Public
+    License as published by the Free Software Foundation; either
+    version 2 of the License, or (at your option) any later version.
 
-  This library is distributed in the hope that it will be useful,
-  but WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-  Library General Public License for more details.
+    This library is distributed in the hope that it will be useful,
+    but WITHOUT ANY WARRANTY; without even the implied warranty of
+    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+    Library General Public License for more details.
 
-  You should have received a copy of the GNU Library General Public License
-  along with this library; see the file COPYING.LIB.  If not, write to
-  the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-  Boston, MA 02110-1301, USA.
+    You should have received a copy of the GNU Library General Public License
+    along with this library; see the file COPYING.LIB.  If not, write to
+    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+    Boston, MA 02110-1301, USA.
 */
 
 #include "Utils.h"
 #include "StringUtils.h"
 #include "HierarchyUtils.h"
-#include "ContextUtils.h"
 #include "StmtBodyRange.h"
+#include "clazy_stl.h"
 
 #include <clang/AST/Expr.h>
-#include <clang/AST/StmtCXX.h>
-#include <clang/AST/ASTContext.h>
 #include <clang/AST/DeclCXX.h>
 #include <clang/AST/DeclTemplate.h>
-#include <clang/AST/DeclFriend.h>
 #include <clang/AST/ExprCXX.h>
 #include <clang/Basic/SourceLocation.h>
-#include <clang/Frontend/CompilerInstance.h>
-#include <clang/AST/ParentMap.h>
 #include <clang/Lex/Lexer.h>
+#include <clang/AST/Decl.h>
+#include <clang/AST/DeclBase.h>
+#include <clang/AST/DeclGroup.h>
+#include <clang/AST/OperationKinds.h>
+#include <clang/AST/Stmt.h>
+#include <clang/AST/StmtIterator.h>
+#include <clang/AST/Type.h>
+#include <clang/Basic/CharInfo.h>
+#include <clang/Basic/IdentifierTable.h>
+#include <clang/Basic/LLVM.h>
+#include <clang/Basic/SourceManager.h>
+#include <clang/Lex/Token.h>
+#include <llvm/Support/Casting.h>
 
 #include <cctype>
-#include <sstream>
+#include <iterator>
+#include <utility>
+
+namespace clang {
+class LangOptions;
+}  // namespace clang
 
 using namespace clang;
 using namespace std;
@@ -130,7 +143,7 @@ bool Utils::childsHaveSideEffects(Stmt *stm)
     if (memberCall) {
         auto methodDecl = dyn_cast<CXXMethodDecl>(memberCall->getMemberDecl());
         if (methodDecl && !methodDecl->isConst() && !methodDecl->isStatic() &&
-                !clazy::contains(method_blacklist, clazy::name(methodDecl)))
+            !clazy::contains(method_blacklist, clazy::name(methodDecl)))
             return true;
     }
 
@@ -230,7 +243,7 @@ ValueDecl *Utils::valueDeclForOperatorCall(CXXOperatorCallExpr *operatorCall)
 clang::ValueDecl * Utils::valueDeclForCallExpr(clang::CallExpr *expr)
 {
     if (auto memberExpr = dyn_cast<CXXMemberCallExpr>(expr)) {
-       return valueDeclForMemberCall(memberExpr);
+        return valueDeclForMemberCall(memberExpr);
     } else if (auto operatorExpr = dyn_cast<CXXOperatorCallExpr>(expr)) {
         return valueDeclForOperatorCall(operatorExpr);
     }
@@ -541,7 +554,7 @@ bool Utils::presumedLocationsEqual(const clang::PresumedLoc &l1, const clang::Pr
 {
     return l1.isValid() && l2.isValid() && l1.getColumn() == l2.getColumn() &&
            l1.getLine()   == l2.getLine()   &&
-            StringRef(l1.getFilename()) == StringRef(l2.getFilename());
+           StringRef(l1.getFilename()) == StringRef(l2.getFilename());
 }
 
 CXXRecordDecl *Utils::isMemberVariable(ValueDecl *decl)
@@ -862,7 +875,10 @@ bool Utils::ctorInitializerContainsMove(const vector<CXXCtorInitializer*> &ctorI
 
 string Utils::filenameForLoc(SourceLocation loc, const clang::SourceManager &sm)
 {
-    string filename = sm.getFilename(loc);
+    if (loc.isMacroID())
+        loc = sm.getExpansionLoc(loc);
+
+    const string filename = sm.getFilename(loc);
     auto splitted = clazy::splitString(filename, '/');
     if (splitted.empty())
         return {};
@@ -890,7 +906,7 @@ SourceLocation Utils::locForNextToken(SourceLocation loc, const clang::SourceMan
     // Calculate how much whitespace needs to be skipped if any.
     unsigned NumWhitespaceChars = 0;
     const char *TokenEnd = sm.getCharacterData(TokenLoc) +
-            Tok.getLength();
+                           Tok.getLength();
     unsigned char C = *TokenEnd;
     while (isHorizontalWhitespace(C)) {
         C = *(++TokenEnd);
