@@ -68,9 +68,8 @@ enum CheckLevel { // See README.md for what each level does
     CheckLevel0 = 0,
     CheckLevel1,
     CheckLevel2,
-    CheckLevel3 = 3,
     ManualCheckLevel,
-    MaxCheckLevel = CheckLevel3,
+    MaxCheckLevel = CheckLevel2,
     DefaultCheckLevel = CheckLevel1
 };
 
@@ -123,10 +122,6 @@ public:
 
     std::string name() const { return m_name; }
 
-    void setEnabledFixits(int);
-    bool isFixitEnabled(int fixit) const;
-    bool isFixitEnabled() const;
-
     void emitWarning(const clang::Decl *, const std::string &error, bool printWarningTag = true);
     void emitWarning(const clang::Stmt *, const std::string &error, bool printWarningTag = true);
     void emitWarning(clang::SourceLocation loc, const std::string &error, bool printWarningTag = true);
@@ -159,11 +154,13 @@ protected:
     bool shouldIgnoreFile(clang::SourceLocation) const;
     void reallyEmitWarning(clang::SourceLocation loc, const std::string &error, const std::vector<clang::FixItHint> &fixits);
 
-    void queueManualFixitWarning(clang::SourceLocation loc, const std::string &message = {}, int fixitType = 1);
+    void queueManualFixitWarning(clang::SourceLocation loc, const std::string &message = {});
     bool warningAlreadyEmitted(clang::SourceLocation loc) const;
     bool manualFixitAlreadyQueued(clang::SourceLocation loc) const;
     bool isOptionSet(const std::string &optionName) const;
 
+    bool fixitsEnabled() const { return true; } // Fixits are always shown
+
     // 3 shortcuts for stuff that litter the codebase all over.
     const clang::SourceManager &sm() const { return m_sm; }
     const clang::LangOptions &lo() const { return m_astContext.getLangOpts(); }
@@ -180,7 +177,6 @@ private:
     std::vector<unsigned int> m_emittedWarningsInMacro;
     std::vector<unsigned int> m_emittedManualFixItsWarningsInMacro;
     std::vector<std::pair<clang::SourceLocation, std::string>> m_queuedManualInterventionWarnings;
-    int m_enabledFixits = 0;
     const Options m_options;
     const std::string m_tag;
 };
