@@ -1,33 +1,43 @@
 /*
-   This file is part of the clazy static checker.
+    This file is part of the clazy static checker.
 
-  Copyright (C) 2016 Sergio Martins <smartins@kde.org>
+    Copyright (C) 2016 Sergio Martins <smartins@kde.org>
 
-  This library is free software; you can redistribute it and/or
-  modify it under the terms of the GNU Library General Public
-  License as published by the Free Software Foundation; either
-  version 2 of the License, or (at your option) any later version.
+    This library is free software; you can redistribute it and/or
+    modify it under the terms of the GNU Library General Public
+    License as published by the Free Software Foundation; either
+    version 2 of the License, or (at your option) any later version.
 
-  This library is distributed in the hope that it will be useful,
-  but WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-  Library General Public License for more details.
+    This library is distributed in the hope that it will be useful,
+    but WITHOUT ANY WARRANTY; without even the implied warranty of
+    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+    Library General Public License for more details.
 
-  You should have received a copy of the GNU Library General Public License
-  along with this library; see the file COPYING.LIB.  If not, write to
-  the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-  Boston, MA 02110-1301, USA.
+    You should have received a copy of the GNU Library General Public License
+    along with this library; see the file COPYING.LIB.  If not, write to
+    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+    Boston, MA 02110-1301, USA.
 */
 
 #include "container-anti-pattern.h"
 #include "Utils.h"
 #include "StringUtils.h"
-#include "MacroUtils.h"
 #include "LoopUtils.h"
 #include "HierarchyUtils.h"
+#include "SourceCompatibilityHelpers.h"
+#include "clazy_stl.h"
 
-#include <clang/AST/AST.h>
-#include <clang/Lex/Lexer.h>
+#include <clang/AST/Decl.h>
+#include <clang/AST/DeclCXX.h>
+#include <clang/AST/Expr.h>
+#include <clang/AST/ExprCXX.h>
+#include <clang/AST/Stmt.h>
+#include <clang/Basic/LLVM.h>
+#include <llvm/Support/Casting.h>
+
+#include <vector>
+
+class ClazyContext;
 
 using namespace clang;
 using namespace std;
@@ -70,7 +80,7 @@ void ContainerAntiPattern::VisitStmt(clang::Stmt *stmt)
     if (!isInterestingCall(callexpr1))
         return;
 
-    emitWarning(getLocStart(stmt), "allocating an unneeded temporary container");
+    emitWarning(clazy::getLocStart(stmt), "allocating an unneeded temporary container");
 }
 
 bool ContainerAntiPattern::VisitQSet(Stmt *stmt)
@@ -97,7 +107,7 @@ bool ContainerAntiPattern::VisitQSet(Stmt *stmt)
     if (!firstMethod || clazy::qualifiedMethodName(firstMethod) != "QSet::intersect")
         return false;
 
-    emitWarning(getLocStart(stmt), "Use QSet::intersects() instead");
+    emitWarning(clazy::getLocStart(stmt), "Use QSet::intersects() instead");
     return true;
 }
 
@@ -109,7 +119,7 @@ bool ContainerAntiPattern::handleLoop(Stmt *stm)
 
     auto memberExpr = clazy::getFirstChildOfType2<CXXMemberCallExpr>(containerExpr);
     if (isInterestingCall(memberExpr)) {
-        emitWarning(getLocStart(stm), "allocating an unneeded temporary container");
+        emitWarning(clazy::getLocStart(stm), "allocating an unneeded temporary container");
         return true;
     }
 
