@@ -1,33 +1,42 @@
 /*
   This file is part of the clazy static checker.
 
-  Copyright (C) 2017 Sergio Martins <smartins@kde.org>
+    Copyright (C) 2017 Sergio Martins <smartins@kde.org>
 
-  This library is free software; you can redistribute it and/or
-  modify it under the terms of the GNU Library General Public
-  License as published by the Free Software Foundation; either
-  version 2 of the License, or (at your option) any later version.
+    This library is free software; you can redistribute it and/or
+    modify it under the terms of the GNU Library General Public
+    License as published by the Free Software Foundation; either
+    version 2 of the License, or (at your option) any later version.
 
-  This library is distributed in the hope that it will be useful,
-  but WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-  Library General Public License for more details.
+    This library is distributed in the hope that it will be useful,
+    but WITHOUT ANY WARRANTY; without even the implied warranty of
+    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+    Library General Public License for more details.
 
-  You should have received a copy of the GNU Library General Public License
-  along with this library; see the file COPYING.LIB.  If not, write to
-  the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-  Boston, MA 02110-1301, USA.
+    You should have received a copy of the GNU Library General Public License
+    along with this library; see the file COPYING.LIB.  If not, write to
+    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+    Boston, MA 02110-1301, USA.
 */
 
 #include "lambda-unique-connection.h"
-#include "Utils.h"
 #include "HierarchyUtils.h"
 #include "QtUtils.h"
-#include "TypeUtils.h"
-#include "AccessSpecifierManager.h"
-#include "ClazyContext.h"
 
-#include <clang/AST/AST.h>
+#include <clang/AST/Decl.h>
+#include <clang/AST/DeclTemplate.h>
+#include <clang/AST/Expr.h>
+#include <clang/AST/Stmt.h>
+#include <clang/Basic/LLVM.h>
+#include <llvm/ADT/StringRef.h>
+#include <llvm/Support/Casting.h>
+
+#include <vector>
+
+class ClazyContext;
+namespace clang {
+class CXXMethodDecl;
+}  // namespace clang
 
 using namespace clang;
 using namespace std;
@@ -59,7 +68,7 @@ void LambdaUniqueConnection::VisitStmt(clang::Stmt *stmt)
     bool found = false;
     for (auto declRef : result) {
         if (auto enumConstant = dyn_cast<EnumConstantDecl>(declRef->getDecl())) {
-            if (enumConstant->getName() == "UniqueConnection") {
+            if (clazy::name(enumConstant) == "UniqueConnection") {
                 found = true;
                 break;
             }
