@@ -224,9 +224,6 @@ CaseStmt* getCaseStatement(clang::ParentMap *pmap, Stmt *stmt, DeclRefExpr *even
             auto switchStmt = clazy::getSwitchFromCase(pmap, caseStmt);
             if (switchStmt) {
                 auto declRef = clazy::getFirstChildOfType2<DeclRefExpr>(switchStmt->getCond());
-
-                switchStmt->getCond()->dump();
-
                 // Does this switch refer to the same QEvent ?
                 if (declRef && declRef->getDecl() == event->getDecl())
                     return caseStmt;
@@ -248,7 +245,7 @@ void WrongQEventCast::VisitStmt(clang::Stmt *stmt)
     Expr *e = cast->getSubExpr();
 
     QualType t = e ? e->getType() : QualType();
-    QualType pointeeType = t.isNull() ? QualType() : TypeUtils::pointeeQualType(t);
+    QualType pointeeType = t.isNull() ? QualType() : clazy::pointeeQualType(t);
     CXXRecordDecl *rec = pointeeType.isNull() ? nullptr : pointeeType->getAsCXXRecordDecl();
 
     if (!rec || clazy::name(rec) != "QEvent")
