@@ -47,7 +47,7 @@ using namespace std;
 
 static bool isQStringBuilder(QualType t)
 {
-    CXXRecordDecl *record = TypeUtils::typeAsRecord(t);
+    CXXRecordDecl *record = clazy::typeAsRecord(t);
     return record && clazy::name(record) == "QStringBuilder";
 }
 
@@ -68,7 +68,7 @@ void AutoUnexpectedQStringBuilder::VisitDecl(Decl *decl)
         return;
 
     std::vector<FixItHint> fixits;
-    if (isFixitEnabled()) {
+    if (fixitsEnabled()) {
         std::string replacement = "QString " + clazy::name(varDecl).str();
 
         if (qualtype.isConstQualified())
