@@ -53,10 +53,55 @@ enum Fixit {
     Fixit_AddqAsConst = 2
 };
 
+namespace clazy {
+/**
+ * Returns true if we can prove the container doesn't detach.
+ * Returns false otherwise, meaning that you can't conclude anything if false is returned.
+ *
+ * For true to be returned, all these conditions must verify:
+ * - Container is a local variable
+ * - It's not passed to any function
+ * - It's not assigned to another variable
+ */
+bool containerNeverDetaches(const clang::VarDecl *valDecl, StmtBodyRange bodyRange) // clazy:exclude=function-args-by-value
+{
+    // This helps for bug 367485
+
+    if (!valDecl)
+        return false;
+
+    const auto context = dyn_cast<FunctionDecl>(valDecl->getDeclContext());
+    if (!context)
+        return false;
+
+    bodyRange.body = context->getBody();
+    if (!bodyRange.body)
+        return false;
+
+    if (valDecl->hasInit()) {
+        if (auto cleanupExpr = dyn_cast<clang::ExprWithCleanups>(valDecl->getInit())) {
+            if (auto ce = dyn_cast<clang::CXXConstructExpr>(cleanupExpr->getSubExpr())) {
+                if (!ce->isListInitialization() && !ce->isStdInitListInitialization()) {
+                    // When initing via copy or move ctor there's possible detachments.
+                    return false;
+                }
+            }
+        }
+    }
+
+    // TODO1: Being passed to a function as const should be OK
+    if (Utils::isPassedToFunction(bodyRange, valDecl, false))
+        return false;
+
+    return true;
+}
+}
+
+
 RangeLoop::RangeLoop(const std::string &name, ClazyContext *context)
     : CheckBase(name, context, Option_CanIgnoreIncludes)
 {
-    if (isFixitEnabled(Fixit_AddqAsConst)) {
+    if (fixitsEnabled()) {
         context->enablePreprocessorVisitor();
     }
 }
@@ -104,7 +149,7 @@ void RangeLoop::processForRangeLoop(CXXForRangeStmt *rangeLoop)
         return;
 
     auto loopVariableType = rangeLoop->getLoopVariable()->getType();
-    if (!TypeUtils::unrefQualType(loopVariableType).isConstQualified() && loopVariableType->isReferenceType())
+    if (!clazy::unrefQualType(loopVariableType).isConstQualified() && loopVariableType->isReferenceType())
         return;
 
     CXXRecordDecl *record = t->getAsCXXRecordDecl();
@@ -118,7 +163,7 @@ void RangeLoop::processForRangeLoop(CXXForRangeStmt *rangeLoop)
     std::vector<FixItHint> fixits;
 
     SourceLocation end;
-    if (isFixitEnabled(Fixit_AddqAsConst) && islvalue(containerExpr, end)) {
+    if (fixitsEnabled() && islvalue(containerExpr, /*by-ref*/end)) {
         PreProcessorVisitor *preProcessorVisitor = m_context->preprocessorVisitor;
         if (!preProcessorVisitor || preProcessorVisitor->qtVersion() >= 50700) { // qAsConst() was added to 5.7
             SourceLocation start = clazy::getLocStart(containerExpr);
@@ -133,9 +178,9 @@ void RangeLoop::processForRangeLoop(CXXForRangeStmt *rangeLoop)
 
 void RangeLoop::checkPassByConstRefCorrectness(CXXForRangeStmt *rangeLoop)
 {
-    TypeUtils::QualTypeClassification classif;
+    clazy::QualTypeClassification classif;
     auto varDecl = rangeLoop->getLoopVariable();
-    bool success = TypeUtils::classifyQualType(m_context, varDecl, /*by-ref*/ classif, rangeLoop);
+    bool success = varDecl && clazy::classifyQualType(m_context, varDecl->getType(), varDecl, /*by-ref*/ classif, rangeLoop);
     if (!success)
         return;
 
@@ -145,7 +190,7 @@ void RangeLoop::checkPassByConstRefCorrectness(CXXForRangeStmt *rangeLoop)
         msg = "Missing reference in range-for with non trivial type (" + paramStr + ')';
 
         std::vector<FixItHint> fixits;
-        if (isFixitEnabled(Fixit_AddRef)) {
+        if (fixitsEnabled()) {
             const bool isConst = varDecl->getType().isConstQualified();
 
             if (!isConst) {
