@@ -145,7 +145,7 @@ void FunctionArgsByValue::processFunction(FunctionDecl *func)
     int i = -1;
     for (auto param : Utils::functionParameters(func)) {
         i++;
-        QualType paramQt = TypeUtils::unrefQualType(param->getType());
+        const QualType paramQt = clazy::unrefQualType(param->getType());
         const Type *paramType = paramQt.getTypePtrOrNull();
         if (!paramType || paramType->isIncompleteType() || paramType->isDependentType())
             continue;
@@ -153,8 +153,8 @@ void FunctionArgsByValue::processFunction(FunctionDecl *func)
         if (shouldIgnoreClass(paramType->getAsCXXRecordDecl()))
             continue;
 
-        TypeUtils::QualTypeClassification classif;
-        bool success = TypeUtils::classifyQualType(m_context, param, classif, body);
+        clazy::QualTypeClassification classif;
+        bool success = clazy::classifyQualType(m_context, param->getType(), param, classif, body);
         if (!success)
             continue;
 
@@ -183,7 +183,7 @@ void FunctionArgsByValue::processFunction(FunctionDecl *func)
             std::vector<FixItHint> fixits;
             auto method = dyn_cast<CXXMethodDecl>(func);
             const bool isVirtualMethod = method && method->isVirtual();
-            if ((!isVirtualMethod || warnForOverriddenMethods) && isFixitEnabled()) { // Don't try to fix virtual methods, as build can fail
+            if ((!isVirtualMethod || warnForOverriddenMethods) && fixitsEnabled()) { // Don't try to fix virtual methods, as build can fail
                 for (auto redecl : func->redecls()) { // Fix in both header and .cpp
                     auto fdecl = dyn_cast<FunctionDecl>(redecl);
                     const ParmVarDecl *param = fdecl->getParamDecl(i);
@@ -199,9 +199,9 @@ void FunctionArgsByValue::processFunction(FunctionDecl *func)
 }
 
 FixItHint FunctionArgsByValue::fixit(FunctionDecl *func, const ParmVarDecl *param,
-                                     TypeUtils::QualTypeClassification)
+                                     clazy::QualTypeClassification)
 {
-    QualType qt = TypeUtils::unrefQualType(param->getType());
+    QualType qt = clazy::unrefQualType(param->getType());
     qt.removeLocalConst();
     const string typeName = qt.getAsString(PrintingPolicy(lo()));
     string replacement = typeName + ' ' + string(clazy::name(param));
