@@ -1,36 +1,43 @@
 /*
-   This file is part of the clazy static checker.
+    This file is part of the clazy static checker.
 
-  Copyright (C) 2015 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
-  Author: Sérgio Martins <sergio.martins@kdab.com>
+    Copyright (C) 2015 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
+    Author: Sérgio Martins <sergio.martins@kdab.com>
 
-  Copyright (C) 2015-2016 Sergio Martins <smartins@kde.org>
+    Copyright (C) 2015-2016 Sergio Martins <smartins@kde.org>
 
-  This library is free software; you can redistribute it and/or
-  modify it under the terms of the GNU Library General Public
-  License as published by the Free Software Foundation; either
-  version 2 of the License, or (at your option) any later version.
+    This library is free software; you can redistribute it and/or
+    modify it under the terms of the GNU Library General Public
+    License as published by the Free Software Foundation; either
+    version 2 of the License, or (at your option) any later version.
 
-  This library is distributed in the hope that it will be useful,
-  but WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-  Library General Public License for more details.
+    This library is distributed in the hope that it will be useful,
+    but WITHOUT ANY WARRANTY; without even the implied warranty of
+    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+    Library General Public License for more details.
 
-  You should have received a copy of the GNU Library General Public License
-  along with this library; see the file COPYING.LIB.  If not, write to
-  the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-  Boston, MA 02110-1301, USA.
+    You should have received a copy of the GNU Library General Public License
+    along with this library; see the file COPYING.LIB.  If not, write to
+    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+    Boston, MA 02110-1301, USA.
 */
 
 #include "missing-typeinfo.h"
-#include "Utils.h"
 #include "TemplateUtils.h"
-#include "TypeUtils.h"
 #include "QtUtils.h"
 #include "StringUtils.h"
+#include "SourceCompatibilityHelpers.h"
 
-#include <clang/AST/AST.h>
 #include <clang/AST/DeclTemplate.h>
+#include <clang/AST/DeclCXX.h>
+#include <clang/AST/Type.h>
+#include <clang/Basic/SourceManager.h>
+#include <llvm/ADT/StringRef.h>
+
+class ClazyContext;
+namespace clang {
+class Decl;
+}  // namespace clang
 
 using namespace std;
 using namespace clang;
@@ -46,8 +53,8 @@ void MissingTypeInfo::VisitDecl(clang::Decl *decl)
     if (!tstdecl)
         return;
 
-    const bool isQList = tstdecl->getName() == "QList";
-    const bool isQVector = isQList ? false : tstdecl->getName() == "QVector";
+    const bool isQList = clazy::name(tstdecl) == "QList";
+    const bool isQVector = isQList ? false : clazy::name(tstdecl) == "QVector";
 
     if (!isQList && !isQVector) {
         registerQTypeInfo(tstdecl);
@@ -64,10 +71,10 @@ void MissingTypeInfo::VisitDecl(clang::Decl *decl)
     const bool isTooBigForQList = isQList && clazy::isTooBigForQList(qt2, &m_astContext);
 
     if ((isQVector || isTooBigForQList) && isCopyable) {
-        if (sm().isInSystemHeader(getLocStart(record)))
+        if (sm().isInSystemHeader(clazy::getLocStart(record)))
             return;
 
-        std::string typeName = record->getName();
+        std::string typeName = clazy::name(record);
         if (typeName == "QPair") // QPair doesn't use Q_DECLARE_TYPEINFO, but rather a explicit QTypeInfo.
             return;
 
@@ -78,8 +85,8 @@ void MissingTypeInfo::VisitDecl(clang::Decl *decl)
 
 void MissingTypeInfo::registerQTypeInfo(ClassTemplateSpecializationDecl *decl)
 {
-    if (decl->getName() == "QTypeInfo") {
-        const string typeName = clazy::getTemplateArgumentTypeStr(decl, 0, lo(), /**recordOnly=*/true);
+    if (clazy::name(decl) == "QTypeInfo") {
+        const string typeName = clazy::getTemplateArgumentTypeStr(decl, 0, lo(), /**recordOnly=*/ true);
         if (!typeName.empty())
             m_typeInfos.insert(typeName);
     }
