@@ -97,7 +97,8 @@ enum ConnectFlag {
     ConnectFlag_QStateAddTransition = 0x400,
     ConnectFlag_QMenuAddAction = 0x800,
     ConnectFlag_QMessageBoxOpen = 0x1000,
-    ConnectFlag_Bogus = 0x2000
+    ConnectFlag_QSignalSpy = 0x2000,
+    ConnectFlag_Bogus = 0x4000
 };
 
 static bool classIsOk(StringRef className)
@@ -113,7 +114,8 @@ OldStyleConnect::OldStyleConnect(const std::string &name, ClazyContext *context)
     context->enableAccessSpecifierManager();
 }
 
-int OldStyleConnect::classifyConnect(FunctionDecl *connectFunc, CallExpr *connectCall)
+template <typename T>
+int OldStyleConnect::classifyConnect(FunctionDecl *connectFunc, T *connectCall) const
 {
     int classification = ConnectFlag_None;
 
@@ -130,6 +132,8 @@ int OldStyleConnect::classifyConnect(FunctionDecl *connectFunc, CallExpr *connec
         classification |= ConnectFlag_QMenuAddAction;
     else if (methodName == "QMessageBox::open")
         classification |= ConnectFlag_QMessageBoxOpen;
+    else if (methodName == "QSignalSpy::QSignalSpy")
+        classification |= ConnectFlag_QSignalSpy;
 
     if (classification == ConnectFlag_None)
         return classification;
@@ -139,7 +143,7 @@ int OldStyleConnect::classifyConnect(FunctionDecl *connectFunc, CallExpr *connec
     else
         classification |= ConnectFlag_OldStyle;
 
-    const int numParams = connectFunc->getNumParams();
+    const unsigned int numParams = connectFunc->getNumParams();
 
     if (classification & ConnectFlag_Connect) {
         if (numParams == 5) {
@@ -185,6 +189,8 @@ int OldStyleConnect::classifyConnect(FunctionDecl *connectFunc, CallExpr *connec
             classification |= ConnectFlag_OldStyleButNonLiteral;
         } else if ((classification & ConnectFlag_QMessageBoxOpen) && numLiterals != 1) {
             classification |= ConnectFlag_OldStyleButNonLiteral;
+        } else if ((classification & ConnectFlag_QSignalSpy) && numLiterals != 1) {
+            classification |= ConnectFlag_OldStyleButNonLiteral;
         }
     }
 
@@ -221,14 +227,16 @@ bool OldStyleConnect::isPrivateSlot(const string &name) const
 void OldStyleConnect::VisitStmt(Stmt *s)
 {
     auto call = dyn_cast<CallExpr>(s);
-    if (!call)
+    auto ctorExpr = call ? nullptr : dyn_cast<CXXConstructExpr>(s);
+    if (!call && !ctorExpr)
         return;
 
     if (m_context->lastMethodDecl && m_context->isQtDeveloper() && m_context->lastMethodDecl->getParent() &&
         clazy::name(m_context->lastMethodDecl->getParent()) == "QObject") // Don't warn of stuff inside qobject.h
         return;
 
-    FunctionDecl *function = call->getDirectCallee();
+    FunctionDecl *function = call ? call->getDirectCallee()
+                                  : ctorExpr->getConstructor();
     if (!function)
         return;
 
@@ -236,7 +244,9 @@ void OldStyleConnect::VisitStmt(Stmt *s)
     if (!method)
         return;
 
-    const int classification = classifyConnect(method, call);
+    const int classification = call ? classifyConnect(method, call)
+                                    : classifyConnect(method, ctorExpr);
+
     if (!(classification & ConnectFlag_OldStyle))
         return;
 
@@ -248,7 +258,8 @@ void OldStyleConnect::VisitStmt(Stmt *s)
         return;
     }
 
-    emitWarning(clazy::getLocStart(s), "Old Style Connect", fixits(classification, call));
+    emitWarning(clazy::getLocStart(s), "Old Style Connect", call ? fixits(classification, call)
+                                                                 : fixits(classification, ctorExpr));
 }
 
 void OldStyleConnect::addPrivateSlot(const PrivateSlot &slot)
@@ -308,33 +319,36 @@ bool OldStyleConnect::isSignalOrSlot(SourceLocation loc, string &macroName) cons
     return macroName == "SIGNAL" || macroName == "SLOT";
 }
 
-vector<FixItHint> OldStyleConnect::fixits(int classification, CallExpr *call)
+template <typename T>
+vector<FixItHint> OldStyleConnect::fixits(int classification, T *callOrCtor)
 {
-    if (!isFixitEnabled())
+    if (!fixitsEnabled())
         return {};
 
-    if (!call) {
+    if (!callOrCtor) {
         llvm::errs() << "Call is invalid\n";
         return {};
     }
 
+    const SourceLocation locStart = clazy::getLocStart(callOrCtor);
+
     if (classification & ConnectFlag_2ArgsDisconnect) {
         // Not implemented yet
         string msg = "Fix it not implemented for disconnect with 2 args";
-        queueManualFixitWarning(clazy::getLocStart(call), msg);
+        queueManualFixitWarning(locStart, msg);
         return {};
     }
 
     if (classification & ConnectFlag_3ArgsDisconnect) {
         // Not implemented yet
         string msg = "Fix it not implemented for disconnect with 3 args";
-        queueManualFixitWarning(clazy::getLocStart(call), msg);
+        queueManualFixitWarning(locStart, msg);
         return {};
     }
 
     if (classification & ConnectFlag_QMessageBoxOpen) {
         string msg = "Fix it not implemented for QMessageBox::open()";
-        queueManualFixitWarning(clazy::getLocStart(call), msg);
+        queueManualFixitWarning(locStart, msg);
         return {};
     }
 
@@ -343,14 +357,14 @@ vector<FixItHint> OldStyleConnect::fixits(int classification, CallExpr *call)
     string implicitCallee;
     string macroName;
     CXXMethodDecl *senderMethod = nullptr;
-    for (auto arg : call->arguments()) {
+    for (auto arg : callOrCtor->arguments()) {
         SourceLocation s = clazy::getLocStart(arg);
         static const CXXRecordDecl *lastRecordDecl = nullptr;
         if (isSignalOrSlot(s, macroName)) {
             macroNum++;
             if (!lastRecordDecl && (classification & ConnectFlag_4ArgsConnect)) {
                 // This means it's a connect with implicit receiver
-                lastRecordDecl = Utils::recordForMemberCall(dyn_cast<CXXMemberCallExpr>(call), implicitCallee);
+                lastRecordDecl = Utils::recordForMemberCall(dyn_cast<CXXMemberCallExpr>(callOrCtor), implicitCallee);
 
                 if (macroNum == 1)
                     llvm::errs() << "This first macro shouldn't enter this path";
@@ -394,7 +408,6 @@ vector<FixItHint> OldStyleConnect::fixits(int classification, CallExpr *call)
                 AccessSpecifierManager *a = m_context->accessSpecifierManager;
                 if (!a)
                     return {};
-
                 const bool isSignal = a->qtAccessSpecifierType(methods[0]) == QtAccessSpecifier_Signal;
                 if (isSignal && macroName == "SLOT") {
                     // The method is actually a signal and the user used SLOT()
@@ -454,13 +467,13 @@ vector<FixItHint> OldStyleConnect::fixits(int classification, CallExpr *call)
 
             string qualifiedName;
             auto contextRecord = clazy::firstContextOfType<CXXRecordDecl>(m_context->lastDecl->getDeclContext());
-            const bool isInInclude = sm().getMainFileID() != sm().getFileID(clazy::getLocStart(call));
+            const bool isInInclude = sm().getMainFileID() != sm().getFileID(locStart);
 
             if (isSpecialProtectedCase && contextRecord) {
                 // We're inside a derived class trying to take address of a protected base member, must use &Derived::method instead of &Base::method.
                 qualifiedName = contextRecord->getNameAsString() + "::" + methodDecl->getNameAsString();
             } else {
-                qualifiedName = clazy::getMostNeededQualifiedName(sm(), methodDecl, context, clazy::getLocStart(call), !isInInclude); // (In includes ignore using directives)
+                qualifiedName = clazy::getMostNeededQualifiedName(sm(), methodDecl, context, locStart, !isInInclude); // (In includes ignore using directives)
             }
 
             CharSourceRange expansionRange = clazy::getImmediateExpansionRange(s, sm());
