@@ -68,9 +68,15 @@ protected:
     void VisitMacroExpands(const clang::Token &macroNameTok, const clang::SourceRange &, const clang::MacroInfo *minfo = nullptr) override;
 private:
     std::string signalOrSlotNameFromMacro(clang::SourceLocation macroLoc);
-    std::vector<clang::FixItHint> fixits(int classification, clang::CallExpr *);
+
+    template <typename T>
+    std::vector<clang::FixItHint> fixits(int classification, T *callOrCtor);
+
     bool isSignalOrSlot(clang::SourceLocation loc, std::string &macroName) const;
-    int classifyConnect(clang::FunctionDecl *connectFunc, clang::CallExpr *connectCall);
+
+    template <typename T>
+    int classifyConnect(clang::FunctionDecl *connectFunc, T *connectCall) const;
+
     bool isQPointer(clang::Expr *expr) const;
     bool isPrivateSlot(const std::string &name) const;
     PrivateSlot::List m_privateSlots;
