@@ -147,14 +147,14 @@ static bool containsStringLiteralNoCallExpr(Stmt *stmt)
     if (!stmt)
         return false;
 
-    StringLiteral *sl = dyn_cast<StringLiteral>(stmt);
+    auto sl = dyn_cast<StringLiteral>(stmt);
     if (sl)
         return true;
 
     for (auto child : stmt->children()) {
         if (!child)
             continue;
-        CallExpr *callExpr = dyn_cast<CallExpr>(child);
+        auto callExpr = dyn_cast<CallExpr>(child);
         if (!callExpr && containsStringLiteralNoCallExpr(child))
             return true;
     }
@@ -175,7 +175,7 @@ static StringLiteral* stringLiteralForCall(Stmt *call)
 
 void QStringAllocations::VisitCtor(Stmt *stm)
 {
-    CXXConstructExpr *ctorExpr = dyn_cast<CXXConstructExpr>(stm);
+    auto ctorExpr = dyn_cast<CXXConstructExpr>(stm);
     if (!Utils::containsStringLiteral(ctorExpr, /**allowEmpty=*/ true))
         return;
 
@@ -229,16 +229,16 @@ void QStringAllocations::VisitCtor(Stmt *stm)
         }
 
         vector<FixItHint> fixits;
-        if (qlatin1expr.enableFixit && isFixitEnabled(QLatin1StringAllocations)) {
+        if (qlatin1expr.enableFixit && fixitsEnabled()) {
             if (!clazy::getLocStart(qlatin1Ctor).isMacroID()) {
                 if (!ternary) {
-                    fixits = fixItReplaceWordWithWord(qlatin1Ctor, "QStringLiteral", "QLatin1String", QLatin1StringAllocations);
+                    fixits = fixItReplaceWordWithWord(qlatin1Ctor, "QStringLiteral", "QLatin1String");
                     bool shouldRemoveQString = clazy::getLocStart(qlatin1Ctor).getRawEncoding() != clazy::getLocStart(stm).getRawEncoding() && dyn_cast_or_null<CXXBindTemporaryExpr>(clazy::parent(m_context->parentMap, ctorExpr));
                     if (shouldRemoveQString) {
                         // This is the case of QString(QLatin1String("foo")), which we just fixed to be QString(QStringLiteral("foo)), so now remove QString
                         auto removalFixits = clazy::fixItRemoveToken(&m_astContext, ctorExpr, true);
                         if (removalFixits.empty())  {
-                            queueManualFixitWarning(clazy::getLocStart(ctorExpr), "Internal error: invalid start or end location", QLatin1StringAllocations);
+                            queueManualFixitWarning(clazy::getLocStart(ctorExpr), "Internal error: invalid start or end location");
                         } else {
                             clazy::append(removalFixits, fixits);
                         }
@@ -247,18 +247,18 @@ void QStringAllocations::VisitCtor(Stmt *stm)
                     fixits = fixItReplaceWordWithWordInTernary(ternary);
                 }
             } else {
-                queueManualFixitWarning(clazy::getLocStart(qlatin1Ctor), "Can't use QStringLiteral in macro", QLatin1StringAllocations);
+                queueManualFixitWarning(clazy::getLocStart(qlatin1Ctor), "Can't use QStringLiteral in macro");
             }
         }
 
-        emitWarning(clazy::getLocStart(stm), msg, fixits);
+        maybeEmitWarning(clazy::getLocStart(stm), msg, fixits);
     } else {
         vector<FixItHint> fixits;
         if (clazy::hasChildren(ctorExpr)) {
             auto pointerDecay = dyn_cast<ImplicitCastExpr>(*(ctorExpr->child_begin()));
             if (clazy::hasChildren(pointerDecay)) {
-                StringLiteral *lt = dyn_cast<StringLiteral>(*pointerDecay->child_begin());
-                if (lt && isFixitEnabled(CharPtrAllocations)) {
+                auto lt = dyn_cast<StringLiteral>(*pointerDecay->child_begin());
+                if (lt && fixitsEnabled()) {
                     Stmt *grandParent = clazy::parent(m_context->parentMap, lt, 2);
                     Stmt *grandGrandParent = clazy::parent(m_context->parentMap, lt, 3);
                     Stmt *grandGrandGrandParent = clazy::parent(m_context->parentMap, lt, 4);
@@ -267,11 +267,11 @@ void QStringAllocations::VisitCtor(Stmt *stm)
 
                         const bool literalIsEmpty = lt->getLength() == 0;
                         if (literalIsEmpty && clazy::getFirstParentOfType<MemberExpr>(m_context->parentMap, ctorExpr) == nullptr)
-                            fixits = fixItReplaceWordWithWord(ctorExpr, "QLatin1String", "QString", CharPtrAllocations);
+                            fixits = fixItReplaceWordWithWord(ctorExpr, "QLatin1String", "QString");
                         else if (!clazy::getLocStart(ctorExpr).isMacroID())
-                            fixits = fixItReplaceWordWithWord(ctorExpr, "QStringLiteral", "QString", CharPtrAllocations);
+                            fixits = fixItReplaceWordWithWord(ctorExpr, "QStringLiteral", "QString");
                         else
-                            queueManualFixitWarning(clazy::getLocStart(ctorExpr), "Can't use QStringLiteral in macro.", CharPtrAllocations);
+                            queueManualFixitWarning(clazy::getLocStart(ctorExpr), "Can't use QStringLiteral in macro.");
                     } else {
 
                         auto parentMemberCallExpr = clazy::getFirstParentOfType<CXXMemberCallExpr>(m_context->parentMap, lt, /*maxDepth=*/ 6); // 6 seems like a nice max from the ASTs I've seen
@@ -293,16 +293,16 @@ void QStringAllocations::VisitCtor(Stmt *stm)
             }
         }
 
-        emitWarning(clazy::getLocStart(stm), msg, fixits);
+        maybeEmitWarning(clazy::getLocStart(stm), msg, fixits);
     }
 }
 
-vector<FixItHint> QStringAllocations::fixItReplaceWordWithWord(clang::Stmt *begin, const string &replacement, const string &replacee, int fixitType)
+vector<FixItHint> QStringAllocations::fixItReplaceWordWithWord(clang::Stmt *begin, const string &replacement, const string &replacee)
 {
     StringLiteral *lt = stringLiteralForCall(begin);
     if (replacee == "QLatin1String") {
         if (lt && !Utils::isAscii(lt)) {
-            emitWarning(clazy::getLocStart(lt), "Don't use QLatin1String with non-latin1 literals");
+            maybeEmitWarning(clazy::getLocStart(lt), "Don't use QLatin1String with non-latin1 literals");
             return {};
         }
     }
@@ -313,7 +313,7 @@ vector<FixItHint> QStringAllocations::fixItReplaceWordWithWord(clang::Stmt *begi
     vector<FixItHint> fixits;
     FixItHint fixit = clazy::fixItReplaceWordWithWord(&m_astContext, begin, replacement, replacee);
     if (fixit.isNull()) {
-        queueManualFixitWarning(clazy::getLocStart(begin), "", fixitType);
+        queueManualFixitWarning(clazy::getLocStart(begin), "");
     } else {
         fixits.push_back(fixit);
     }
@@ -324,18 +324,31 @@ vector<FixItHint> QStringAllocations::fixItReplaceWordWithWord(clang::Stmt *begi
 vector<FixItHint> QStringAllocations::fixItReplaceWordWithWordInTernary(clang::ConditionalOperator *ternary)
 {
     vector<CXXConstructExpr*> constructExprs;
-    clazy::getChilds<CXXConstructExpr>(ternary, constructExprs, 1); // depth = 1, only the two immediate expressions
+
+    auto addConstructExpr = [&constructExprs] (Expr* expr) {
+        if (auto functionalCast = dyn_cast<CXXFunctionalCastExpr>(expr)) {
+            expr = functionalCast->getSubExpr();
+        }
+
+        if (auto constructExpr = dyn_cast<CXXConstructExpr>(expr))
+            constructExprs.push_back(constructExpr);
+    };
+
+    addConstructExpr(ternary->getTrueExpr());
+    addConstructExpr(ternary->getFalseExpr());
+
+    if (constructExprs.size() != 2) {
+        llvm::errs() << "Weird ternary operator with " << constructExprs.size()
+                     << " constructExprs at " << clazy::getLocStart(ternary).printToString(sm()) << "\n";
+        ternary->dump();
+        assert(false);
+        return {};
+    }
 
     vector<FixItHint> fixits;
     fixits.reserve(2);
-    if (constructExprs.size() != 2) {
-        llvm::errs() << "Weird ternary operator with " << constructExprs.size() << " at " << clazy::getLocStart(ternary).printToString(sm()) << "\n";
-        assert(false);
-        return fixits;
-    }
-
-    for (int i = 0; i < 2; ++i) {
-        SourceLocation rangeStart = clazy::getLocStart(constructExprs[i]);
+    for (CXXConstructExpr *constructExpr : constructExprs) {
+        SourceLocation rangeStart = clazy::getLocStart(constructExpr);
         SourceLocation rangeEnd = Lexer::getLocForEndOfToken(rangeStart, -1, sm(), lo());
         fixits.push_back(FixItHint::CreateReplacement(SourceRange(rangeStart, rangeEnd), "QStringLiteral"));
     }
@@ -402,9 +415,8 @@ std::vector<FixItHint> QStringAllocations::fixItReplaceFromLatin1OrFromUtf8(Call
 
     std::string replacement = isQStringLiteralCandidate(callExpr, m_context->parentMap, lo(), sm()) ? "QStringLiteral"
                                                                                                     : "QLatin1String";
-
     if (replacement == "QStringLiteral" && clazy::getLocStart(callExpr).isMacroID()) {
-        queueManualFixitWarning(clazy::getLocStart(callExpr), "Can't use QStringLiteral in macro!", FromLatin1_FromUtf8Allocations);
+        queueManualFixitWarning(clazy::getLocStart(callExpr), "Can't use QStringLiteral in macro!");
         return {};
     }
 
@@ -429,7 +441,7 @@ std::vector<FixItHint> QStringAllocations::fixItReplaceFromLatin1OrFromUtf8(Call
         SourceRange range(clazy::getLocStart(callExpr), methodNameLoc);
         fixits.push_back(FixItHint::CreateReplacement(range, replacement));
     } else {
-        queueManualFixitWarning(clazy::getLocStart(callExpr), "Internal error: literal is null", FromLatin1_FromUtf8Allocations);
+        queueManualFixitWarning(clazy::getLocStart(callExpr), "Internal error: literal is null");
     }
 
     return fixits;
@@ -442,21 +454,21 @@ std::vector<FixItHint> QStringAllocations::fixItRawLiteral(clang::StringLiteral
     SourceRange range = clazy::rangeForLiteral(&m_astContext, lt);
     if (range.isInvalid()) {
         if (lt) {
-            queueManualFixitWarning(clazy::getLocStart(lt), "Internal error: Can't calculate source location", CharPtrAllocations);
+            queueManualFixitWarning(clazy::getLocStart(lt), "Internal error: Can't calculate source location");
         }
         return {};
     }
 
     SourceLocation start = clazy::getLocStart(lt);
     if (start.isMacroID()) {
-        queueManualFixitWarning(start, "Can't use QStringLiteral in macro", CharPtrAllocations);
+        queueManualFixitWarning(start, "Can't use QStringLiteral in macro");
     } else {
         if (Utils::literalContainsEscapedBytes(lt, sm(), lo()))
             return {};
 
         string revisedReplacement = lt->getLength() == 0 ? "QLatin1String" : replacement; // QLatin1String("") is better than QStringLiteral("")
         if (revisedReplacement == "QStringLiteral" && clazy::getLocStart(lt).isMacroID()) {
-            queueManualFixitWarning(clazy::getLocStart(lt), "Can't use QStringLiteral in macro...", CharPtrAllocations);
+            queueManualFixitWarning(clazy::getLocStart(lt), "Can't use QStringLiteral in macro...");
             return {};
         }
 
@@ -468,7 +480,7 @@ std::vector<FixItHint> QStringAllocations::fixItRawLiteral(clang::StringLiteral
 
 void QStringAllocations::VisitOperatorCall(Stmt *stm)
 {
-    CXXOperatorCallExpr *operatorCall = dyn_cast<CXXOperatorCallExpr>(stm);
+    auto operatorCall = dyn_cast<CXXOperatorCallExpr>(stm);
     if (!operatorCall)
         return;
 
@@ -489,7 +501,7 @@ void QStringAllocations::VisitOperatorCall(Stmt *stm)
     if (!funcDecl)
         return;
 
-    CXXMethodDecl *methodDecl = dyn_cast<CXXMethodDecl>(funcDecl);
+    auto methodDecl = dyn_cast<CXXMethodDecl>(funcDecl);
     if (!clazy::isOfClass(methodDecl, "QString"))
         return;
 
@@ -507,9 +519,9 @@ void QStringAllocations::VisitOperatorCall(Stmt *stm)
         }
     }
 
-    if (isFixitEnabled(CharPtrAllocations)) {
+    if (fixitsEnabled()) {
         if (literals.empty()) {
-            queueManualFixitWarning(clazy::getLocStart(stm), "Couldn't find literal", CharPtrAllocations);
+            queueManualFixitWarning(clazy::getLocStart(stm), "Couldn't find literal");
         } else {
             const string replacement = Utils::isAscii(literals[0]) ? "QLatin1String" : "QStringLiteral";
             fixits = fixItRawLiteral(literals[0], replacement);
@@ -517,12 +529,12 @@ void QStringAllocations::VisitOperatorCall(Stmt *stm)
     }
 
     string msg = string("QString(const char*) being called");
-    emitWarning(clazy::getLocStart(stm), msg, fixits);
+    maybeEmitWarning(clazy::getLocStart(stm), msg, fixits);
 }
 
 void QStringAllocations::VisitFromLatin1OrUtf8(Stmt *stmt)
 {
-    CallExpr *callExpr = dyn_cast<CallExpr>(stmt);
+    auto callExpr = dyn_cast<CallExpr>(stmt);
     if (!callExpr)
         return;
 
@@ -530,7 +542,7 @@ void QStringAllocations::VisitFromLatin1OrUtf8(Stmt *stmt)
     if (!clazy::functionIsOneOf(functionDecl, {"fromLatin1", "fromUtf8"}))
         return;
 
-    CXXMethodDecl *methodDecl = dyn_cast<CXXMethodDecl>(functionDecl);
+    auto methodDecl = dyn_cast<CXXMethodDecl>(functionDecl);
     if (!clazy::isOfClass(methodDecl, "QString"))
         return;
 
@@ -552,7 +564,7 @@ void QStringAllocations::VisitFromLatin1OrUtf8(Stmt *stmt)
     if (!ternaries.empty()) {
         auto ternary = ternaries[0];
         if (Utils::ternaryOperatorIsOfStringLiteral(ternary)) {
-            emitWarning(clazy::getLocStart(stmt), string("QString::fromLatin1() being passed a literal"));
+            maybeEmitWarning(clazy::getLocStart(stmt), string("QString::fromLatin1() being passed a literal"));
         }
 
         return;
@@ -560,21 +572,21 @@ void QStringAllocations::VisitFromLatin1OrUtf8(Stmt *stmt)
 
     std::vector<FixItHint> fixits;
 
-    if (isFixitEnabled(FromLatin1_FromUtf8Allocations)) {
+    if (fixitsEnabled()) {
         const FromFunction fromFunction = clazy::name(functionDecl) == "fromLatin1" ? FromLatin1 : FromUtf8;
         fixits = fixItReplaceFromLatin1OrFromUtf8(callExpr, fromFunction);
     }
 
     if (clazy::name(functionDecl) == "fromLatin1") {
-        emitWarning(clazy::getLocStart(stmt), string("QString::fromLatin1() being passed a literal"), fixits);
+        maybeEmitWarning(clazy::getLocStart(stmt), string("QString::fromLatin1() being passed a literal"), fixits);
     } else {
-        emitWarning(clazy::getLocStart(stmt), string("QString::fromUtf8() being passed a literal"), fixits);
+        maybeEmitWarning(clazy::getLocStart(stmt), string("QString::fromUtf8() being passed a literal"), fixits);
     }
 }
 
 void QStringAllocations::VisitAssignOperatorQLatin1String(Stmt *stmt)
 {
-    CXXOperatorCallExpr *callExpr = dyn_cast<CXXOperatorCallExpr>(stmt);
+    auto callExpr = dyn_cast<CXXOperatorCallExpr>(stmt);
     if (!Utils::isAssignOperator(callExpr, "QString", "QLatin1String", lo()))
         return;
 
@@ -589,10 +601,27 @@ void QStringAllocations::VisitAssignOperatorQLatin1String(Stmt *stmt)
 
     vector<FixItHint> fixits;
 
-    if (isFixitEnabled(QLatin1StringAllocations)) {
-        fixits = ternary == nullptr ? fixItReplaceWordWithWord(begin, "QStringLiteral", "QLatin1String", QLatin1StringAllocations)
+    if (fixitsEnabled()) {
+        fixits = ternary == nullptr ? fixItReplaceWordWithWord(begin, "QStringLiteral", "QLatin1String")
                                     : fixItReplaceWordWithWordInTernary(ternary);
     }
 
-    emitWarning(clazy::getLocStart(stmt), string("QString::operator=(QLatin1String(\"literal\")"), fixits);
+    maybeEmitWarning(clazy::getLocStart(stmt), string("QString::operator=(QLatin1String(\"literal\")"), fixits);
+}
+
+void QStringAllocations::maybeEmitWarning(SourceLocation loc, string error, std::vector<FixItHint> fixits)
+{
+    if (clazy::isUIFile(loc, sm())) {
+        // Don't bother warning for generated UI files.
+        // We do the check here instead of at the beginning so users that don't use UI files don't have to pay the performance price.
+        return;
+    }
+
+    if (m_context->isQtDeveloper() && Utils::filenameForLoc(loc, sm()) == "qstring.cpp") {
+        // There's an error replacing an internal fromLatin1() because the replacement code doesn't expect to be working on QString itself
+        // not worth to fix, it's only 1 case in qstring.cpp, and related to Qt 1.x compat
+        fixits = {};
+    }
+
+    emitWarning(loc, error, fixits);
 }
