@@ -1,5 +1,5 @@
 #include <QtCore/QList>
-
+#include <QtCore/QVariant>
 
 
 
@@ -47,3 +47,9 @@ void test_bug358740()
     QList<int> list; // OK
     int a, b;
 }
+
+void testQVariantList()
+{
+    QList<QVariant> list1; // Warn
+    QVariantList list2; // OK, to interact with Qt api probably
+}
