@@ -4,7 +4,7 @@
 #include <QtCore/QSequentialIterable>
 #include <QtCore/QVarLengthArray>
 #include <QtCore/QString>
-
+#include <QtCore/QJsonArray>
 
 
 
@@ -237,3 +237,13 @@ void test_add_qasconst_fixits()
 
     for (const auto &s : f.getList()) {} // Warn
 }
+
+
+void test_json_array()
+{
+    QJsonArray array;
+    const QJsonArray const_array;
+    for (const auto a : array) {} // OK
+    for (const QJsonValue a : const_array) {} // Warn
+    for (const QJsonValue &a : const_array) {} // OK
+}
