@@ -1,9 +1,14 @@
-#!/usr/bin/env python2
+#!/usr/bin/env python3
 
-import sys, os, subprocess, string, re, json, threading, multiprocessing, argparse
+import sys, os, subprocess, string, re, json, threading, multiprocessing, argparse, io
+import shutil
 from threading import Thread
 from sys import platform as _platform
 
+
+# cd into the folder containing this script
+os.chdir(os.path.realpath(os.path.dirname(sys.argv[0])))
+
 _verbose = False
 
 def isWindows():
@@ -25,7 +30,6 @@ class Test:
         self.maximum_qt_version = 59999
         self.minimum_clang_version = 380
         self.compare_everything = False
-        self.isFixedFile = False
         self.link = False # If true we also call the linker
         self.check = check
         self.expects_failure = False
@@ -40,15 +44,41 @@ class Test:
         self.qt_developer = False
         self.header_filter = ""
         self.ignore_dirs = ""
+        self.has_fixits = False
+        self.should_run_fixits_test = False
 
     def filename(self):
         if len(self.filenames) == 1:
             return self.filenames[0]
         return ""
 
+    def relativeFilename(self):
+        # example: "auto-unexpected-qstringbuilder/main.cpp"
+        return self.check.name + "/" + self.filename()
+
+    def yamlFilename(self, is_standalone):
+        # The name of the yaml file with fixits
+        # example: "auto-unexpected-qstringbuilder/main.cpp.clazy.yaml"
+        if is_standalone:
+            return self.relativeFilename() + ".clazy-standalone.yaml"
+        else:
+            return self.relativeFilename() + ".clazy.yaml"
+
+    def fixedFilename(self, is_standalone):
+        if is_standalone:
+            return self.relativeFilename() + ".clazy-standalone.fixed"
+        else:
+            return self.relativeFilename() + ".clazy.fixed"
+
+    def expectedFixedFilename(self):
+        return self.relativeFilename() + ".fixed.expected"
+
     def isScript(self):
         return self.filename().endswith(".sh")
 
+    def dir(self):
+        return self.check.name
+
     def setQtMajorVersion(self, major_version):
         if major_version == 4:
             self.qt_major_version = 4
@@ -64,8 +94,29 @@ class Test:
     def setEnv(self, e):
         self.env = os.environ.copy()
         for key in e:
-            key_str = key.encode('ascii', 'ignore')
-            self.env[key_str] = e[key].encode('ascii', 'ignore')
+            if type(key) is bytes:
+                key = key.decode('utf-8')
+
+            self.env[key] = e[key]
+
+    def printableName(self, is_standalone, is_fixits):
+        name = self.check.name
+        if len(self.check.tests) > 1:
+            name += "/" + self.filename()
+        if is_fixits and is_standalone:
+            name += " (standalone, fixits)"
+        elif is_standalone:
+            name += " (standalone)"
+        elif is_fixits:
+            name += " (plugin, fixits)"
+        else:
+            name += " (plugin)"
+        return name
+
+    def removeYamlFiles(self):
+        for f in [self.yamlFilename(False), self.yamlFilename(True)]:
+            if os.path.exists(f):
+                os.remove(f)
 
 class Check:
     def __init__(self, name):
@@ -80,14 +131,26 @@ class Check:
 # utility functions #1
 
 def get_command_output(cmd, test_env = os.environ):
+    success = True
+
     try:
         if _verbose:
-            print cmd
-        output = subprocess.check_output(cmd, stderr=subprocess.STDOUT, shell=True, env=test_env)
-    except subprocess.CalledProcessError, e:
-        return e.output,False
+            print(cmd)
 
-    return output,True
+        # Polish up the env to fix "TypeError: environment can only contain strings" exception
+        str_env = {}
+        for key in test_env.keys():
+            str_env[str(key)] = str(test_env[key])
+
+        output = subprocess.check_output(cmd, stderr=subprocess.STDOUT, shell=True, env=str_env)
+    except subprocess.CalledProcessError as e:
+        output = e.output
+        success = False
+
+    if type(output) is bytes:
+        output = output.decode('utf-8')
+
+    return output,success
 
 def load_json(check_name):
     check = Check(check_name)
@@ -150,8 +213,6 @@ def load_json(check_name):
                 test.blacklist_platforms = t['blacklist_platforms']
             if 'compare_everything' in t:
                 test.compare_everything = t['compare_everything']
-            if 'isFixedFile' in t:
-                test.isFixedFile = t['isFixedFile']
             if 'link' in t:
                 test.link = t['link']
             if 'qt_major_version' in t:
@@ -164,6 +225,8 @@ def load_json(check_name):
                 test.flags = t['flags']
             if 'must_fail' in t:
                 test.must_fail = t['must_fail']
+            if 'has_fixits' in t:
+                test.has_fixits = t['has_fixits']
             if 'expects_failure' in t:
                 test.expects_failure = t['expects_failure']
             if 'qt4compat' in t:
@@ -181,10 +244,6 @@ def load_json(check_name):
                 test.checks.append(test.check.name)
 
             check.tests.append(test)
-            if test.isFixedFile:
-                fileToDelete = check_name + "/" + test.filename()
-                if os.path.exists(fileToDelete):
-                    os.remove(fileToDelete)
 
     return check
 
@@ -203,11 +262,11 @@ def find_qt_installation(major_version, qmakes):
                 ver = qmake_version_str.split('.')
                 installation.int_version = int(ver[0]) * 10000 + int(ver[1]) * 100 + int(ver[2])
                 if _verbose:
-                    print "Found Qt " + str(installation.int_version) + " using qmake " + qmake
+                    print("Found Qt " + str(installation.int_version) + " using qmake " + qmake)
             break
 
     if installation.int_version == 0 and major_version >= 5: # Don't warn for missing Qt4 headers
-        print "Error: Couldn't find a Qt" + str(major_version) + " installation"
+        print("Error: Couldn't find a Qt" + str(major_version) + " installation")
     return installation
 
 def libraryName():
@@ -228,7 +287,7 @@ def clazy_cpp_args():
     return "-Wno-unused-value -Qunused-arguments -std=c++14 "
 
 def more_clazy_args():
-    return " -Xclang -plugin-arg-clazy -Xclang no-inplace-fixits " + clazy_cpp_args()
+    return " " + clazy_cpp_args()
 
 def clazy_standalone_binary():
     if 'CLAZYSTANDALONE_CXX' in os.environ: # in case we want to use "clazy.AppImage --standalone" instead
@@ -237,10 +296,10 @@ def clazy_standalone_binary():
 
 def clazy_standalone_command(test, qt):
     result = " -- " + clazy_cpp_args() + qt.compiler_flags() + " " + test.flags
-    result = " -no-inplace-fixits -checks=" + string.join(test.checks, ',') + " " + result
+    result = " -checks=" + ','.join(test.checks) + " " + result
 
-    if not test.isFixedFile:
-        result = " -enable-all-fixits " + result
+    if test.has_fixits:
+        result = " -export-fixes=" + test.yamlFilename(is_standalone=True) + result
 
     if test.qt4compat:
         result = " -qt4-compat " + result
@@ -283,9 +342,9 @@ def clazy_command(qt, test, filename):
     else:
         result = result + " -c "
 
-    result = result + test.flags + " -Xclang -plugin-arg-clazy -Xclang " + string.join(test.checks, ',') + " "
-    if not test.isFixedFile: # When compiling the already fixed file disable fixit, we don't want to fix twice
-        result += _enable_fixits_argument + " "
+    result = result + test.flags + " -Xclang -plugin-arg-clazy -Xclang " + ','.join(test.checks) + " "
+    if test.has_fixits:
+        result += _export_fixes_argument + " "
     result += filename
 
     return result
@@ -304,23 +363,25 @@ def compiler_name():
 parser = argparse.ArgumentParser()
 parser.add_argument("-v", "--verbose", action='store_true')
 parser.add_argument("--no-standalone", action='store_true', help="Don\'t run clazy-standalone")
+parser.add_argument("--no-fixits", action='store_true', help='Don\'t run fixits')
 parser.add_argument("--only-standalone", action='store_true', help='Only run clazy-standalone')
 parser.add_argument("--dump-ast", action='store_true', help='Dump a unit-test AST to file')
 parser.add_argument("--exclude", help='Comma separated list of checks to ignore')
-parser.add_argument("check_names", nargs='*', help="The name of the check who's unit-tests will be run. Defaults to running all checks.")
+parser.add_argument("check_names", nargs='*', help="The name of the check whose unit-tests will be run. Defaults to running all checks.")
 args = parser.parse_args()
 
 if args.only_standalone and args.no_standalone:
-    print "Error: --only-standalone is incompatible with --no-standalone"
+    print("Error: --only-standalone is incompatible with --no-standalone")
     sys.exit(1)
 
 #-------------------------------------------------------------------------------
 # Global variables
 
-_enable_fixits_argument = "-Xclang -plugin-arg-clazy -Xclang enable-all-fixits"
+_export_fixes_argument = "-Xclang -plugin-arg-clazy -Xclang export-fixes"
 _dump_ast = args.dump_ast
 _verbose = args.verbose
 _no_standalone = args.no_standalone
+_no_fixits = args.no_fixits
 _only_standalone = args.only_standalone
 _num_threads = multiprocessing.cpu_count()
 _lock = threading.Lock()
@@ -333,7 +394,6 @@ _excluded_checks = args.exclude.split(',') if args.exclude is not None else []
 # utility functions #2
 
 version,success = get_command_output(compiler_name() + ' --version')
-
 match = re.search('clang version (.*?)[ -]', version)
 try:
     version = match.group(1)
@@ -344,11 +404,11 @@ except:
     try:
         version = match.group(1)
     except:
-        print "Could not determine clang version, is it in PATH?"
+        print("Could not determine clang version, is it in PATH?")
         sys.exit(-1)
 
 if _verbose:
-    print 'Found clang version: ' + str(version)
+    print('Found clang version: ' + str(version))
 
 CLANG_VERSION = int(version.replace('.', ''))
 
@@ -366,55 +426,120 @@ def run_command(cmd, output_file = "", test_env = os.environ):
     lines = lines.replace("std::__1::__vector_base_common", "std::_Vector_base") # Hack for macOS
     lines = lines.replace("std::_Vector_alloc", "std::_Vector_base")
     if not success and not output_file:
-        print lines
+        print(lines)
         return False
 
     if _verbose:
-        print "Running: " + cmd
-        print "output_file=" + output_file
+        print("Running: " + cmd)
+        print("output_file=" + output_file)
 
     lines = lines.replace('\r\n', '\n')
     if output_file:
-        f = open(output_file, 'w')
+        f = io.open(output_file, 'w', encoding='utf8')
         f.writelines(lines)
         f.close()
     else:
-        print lines
+        print(lines)
 
     return success
 
 def files_are_equal(file1, file2):
     try:
-        f = open(file1, 'r')
+        f = io.open(file1, 'r', encoding='utf-8')
         lines1 = f.readlines()
         f.close()
 
-        f = open(file2, 'r')
+        f = io.open(file2, 'r', encoding='utf-8')
         lines2 = f.readlines()
         f.close()
 
         return lines1 == lines2
-    except:
+    except Exception as ex:
+        print("Errot comparing files:" + str(ex))
         return False
 
-def get_check_names():
-    return filter(lambda entry: os.path.isdir(entry), os.listdir("."))
+def compare_files(expects_failure, expected_file, result_file, message):
+    success = files_are_equal(expected_file, result_file)
 
-# Returns all files with .cpp_fixed extension. These were rewritten by clang.
-def get_fixed_files():
-    return filter(lambda entry: entry.endswith('.cpp_fixed.cpp'), os.listdir("."))
+    if expects_failure:
+        if success:
+            print("[XOK]   " + message)
+            return False
+        else:
+            print("[XFAIL] " + message)
+            print_differences(expected_file, result_file)
+            return True
+    else:
+        if success:
+            print("[OK]   " + message)
+            return True
+        else:
+            print("[FAIL] " + message)
+            print_differences(expected_file, result_file)
+            return False
+
+def get_check_names():
+    return list(filter(lambda entry: os.path.isdir(entry), os.listdir(".")))
+
+# The yaml file references the test file in our git repo, but we don't want
+# to rewrite that one, as we would need to discard git changes afterwards,
+# so patch the yaml file and add a ".fixed" suffix to those files
+def patch_fixit_yaml_file(test, is_standalone):
+
+    yamlfilename = test.yamlFilename(is_standalone)
+    fixedfilename = test.fixedFilename(is_standalone)
+
+    f = open(yamlfilename, 'r')
+    lines = f.readlines()
+    f.close()
+    f = open(yamlfilename, 'w')
+
+    possible_headerfile = test.relativeFilename().replace(".cpp", ".h")
+
+    for line in lines:
+        stripped = line.strip()
+        if stripped.startswith('MainSourceFile') or stripped.startswith("FilePath") or stripped.startswith("- FilePath"):
+            line = line.replace(test.relativeFilename(), fixedfilename)
+
+            # For Windows:
+            line = line.replace(test.relativeFilename().replace('/', '\\'), fixedfilename.replace('/', '\\'))
+
+            # Some tests also apply fix their to their headers:
+            line = line.replace(possible_headerfile, fixedfilename.replace(".cpp", ".h"))
+        f.write(line)
+    f.close()
+
+    shutil.copyfile(test.relativeFilename(), fixedfilename)
+
+    if os.path.exists(possible_headerfile):
+        shutil.copyfile(possible_headerfile, fixedfilename.replace(".cpp", ".h"))
+
+    return True
+
+def run_clang_apply_replacements():
+    command = os.getenv('CLAZY_CLANG_APPLY_REPLACEMENTS', 'clang-apply-replacements')
+    return run_command(command + ' .')
+
+def cleanup_fixit_files(checks):
+    for check in checks:
+        filestodelete = list(filter(lambda entry: entry.endswith('.fixed') or entry.endswith('.yaml'), os.listdir(check.name)))
+        for f in filestodelete:
+            os.remove(check.name + '/' + f)
 
 def print_differences(file1, file2):
     # Returns true if the the files are equal
-    return run_command("diff -Naur {} {}".format(file1, file2))
+    return run_command("diff -Naur --strip-trailing-cr {} {}".format(file1, file2))
 
 def normalizedCwd():
     return os.getcwd().replace('\\', '/')
 
 def extract_word(word, in_file, out_file):
-    in_f = open(in_file, 'r')
-    out_f = open(out_file, 'w')
+    in_f = io.open(in_file, 'r', encoding='utf-8')
+    out_f = io.open(out_file, 'w', encoding='utf-8')
     for line in in_f:
+        if '[-Wdeprecated-declarations]' in line:
+            continue
+
         if word in line:
             line = line.replace('\\', '/')
             line = line.replace(normalizedCwd() + '/', "") # clazy-standalone prints the complete cpp file path for some reason. Normalize it so it compares OK with the expected output.
@@ -424,11 +549,11 @@ def extract_word(word, in_file, out_file):
 
 def print_file(filename):
     f = open(filename, 'r')
-    print f.read()
+    print(f.read())
     f.close()
 
 def file_contains(filename, text):
-    f = open(filename, 'r')
+    f = io.open(filename, 'r', encoding='utf-8')
     contents = f.read()
     f.close()
     return text in contents
@@ -441,17 +566,17 @@ def run_unit_test(test, is_standalone):
 
     if _verbose:
         print
-        print "Qt version: " + str(qt.int_version)
-        print "Qt headers: " + qt.qmake_header_path
+        print("Qt version: " + str(qt.int_version))
+        print("Qt headers: " + qt.qmake_header_path)
 
     if qt.int_version < test.minimum_qt_version or qt.int_version > test.maximum_qt_version or CLANG_VERSION < test.minimum_clang_version:
         if (_verbose):
-            print "Skipping " + test.check.name + " because required version is not available"
+            print("Skipping " + test.check.name + " because required version is not available")
         return True
 
     if _platform in test.blacklist_platforms:
         if (_verbose):
-            print "Skipping " + test.check.name + " because it is blacklisted for this platform"
+            print("Skipping " + test.check.name + " because it is blacklisted for this platform")
         return True
 
     checkname = test.check.name
@@ -472,9 +597,6 @@ def run_unit_test(test, is_standalone):
     if test.compare_everything:
         result_file = output_file
 
-    if test.isFixedFile:
-        result_file = filename
-
     must_fail = test.must_fail
 
     cmd_success = run_command(cmd_to_run, output_file, test.env)
@@ -483,62 +605,118 @@ def run_unit_test(test, is_standalone):
         return True
 
     if (not cmd_success and not must_fail) or (cmd_success and must_fail):
-        print "[FAIL] " + checkname + " (Failed to build test. Check " + output_file + " for details)"
-        print "-------------------"
-        print "Contents of %s:" % output_file
+        print("[FAIL] " + checkname + " (Failed to build test. Check " + output_file + " for details)")
+        print("-------------------")
+        print("Contents of %s:" % output_file)
         print_file(output_file)
-        print "-------------------"
+        print("-------------------")
         print
         return False
 
-    if not test.compare_everything and not test.isFixedFile:
+    if not test.compare_everything:
         word_to_grep = "warning:" if not must_fail else "error:"
         extract_word(word_to_grep, output_file, result_file)
 
-    printableName = checkname
-    if len(test.check.tests) > 1:
-        printableName += "/" + test.filename()
+    # Check that it printed the expected warnings
+    if not compare_files(test.expects_failure, expected_file, result_file, test.printableName(is_standalone, False)):
+        return False
 
-    if is_standalone:
-        printableName += " (standalone)"
-
-    success = files_are_equal(expected_file, result_file)
-
-    if test.expects_failure:
-        if success:
-            print "[XOK]   " + printableName
-            return False
-        else:
-            print "[XFAIL] " + printableName
-            print_differences(expected_file, result_file)
-    else:
-        if success:
-            print "[OK]   " + printableName
-        else:
-            print "[FAIL] " + printableName
-            print_differences(expected_file, result_file)
-            return False
+    if test.has_fixits:
+        # The normal tests succeeded, we can run the respective fixits then
+        test.should_run_fixits_test = True
 
     return True
 
 def run_unit_tests(tests):
     result = True
     for test in tests:
+        test_result = True
         if not _only_standalone:
-            result = result and run_unit_test(test, False)
+            test_result = run_unit_test(test, False)
+            result = result and test_result
 
         if not _no_standalone:
-            result = result and run_unit_test(test, True)
+            test_result = test_result and run_unit_test(test, True)
+            result = result and test_result
+
+        if not test_result:
+            test.removeYamlFiles()
 
     global _was_successful, _lock
     with _lock:
         _was_successful = _was_successful and result
 
+def patch_yaml_files(requested_checks, is_standalone):
+    if (is_standalone and _no_standalone) or (not is_standalone and _only_standalone):
+        # Nothing to do
+        return True
+
+    success = True
+    for check in requested_checks:
+        for test in check.tests:
+            if test.should_run_fixits_test:
+                yamlfilename = test.yamlFilename(is_standalone)
+                if not os.path.exists(yamlfilename):
+                    print("[FAIL] " + yamlfilename + " is missing!!")
+                    success = False
+                    continue
+                if not patch_fixit_yaml_file(test, is_standalone):
+                    print("[FAIL] Could not patch " + yamlfilename)
+                    success = False
+                    continue
+    return success
+
+def compare_fixit_results(test, is_standalone):
+
+    if (is_standalone and _no_standalone) or (not is_standalone and _only_standalone):
+        # Nothing to do
+        return True
+
+    # Check that the rewritten file is identical to the expected one
+    if not compare_files(False, test.expectedFixedFilename(), test.fixedFilename(is_standalone), test.printableName(is_standalone, True)):
+        return False
+
+    # Some fixed cpp files have an header that was also fixed. Compare it here too.
+    possible_headerfile_expected = test.expectedFixedFilename().replace('.cpp', '.h')
+    if os.path.exists(possible_headerfile_expected):
+        possible_headerfile = test.fixedFilename(is_standalone).replace('.cpp', '.h')
+        if not compare_files(False, possible_headerfile_expected, possible_headerfile, test.printableName(is_standalone, True).replace('.cpp', '.h')):
+            return False
+
+    return True
+
+# This is run sequentially, due to races. As clang-apply-replacements just applies all .yaml files it can find.
+# We run a single clang-apply-replacements invocation, which changes all files in the tests/ directory.
+def run_fixit_tests(requested_checks):
+
+    success = patch_yaml_files(requested_checks, is_standalone=False)
+    success = patch_yaml_files(requested_checks, is_standalone=True) and success
+
+    # Call clazy-apply-replacements[.exe]
+    if not run_clang_apply_replacements():
+        return False
+
+    # Now compare all the *.fixed files with the *.fixed.expected counterparts
+
+    for check in requested_checks:
+        for test in check.tests:
+            if test.should_run_fixits_test:
+                # Check that the rewritten file is identical to the expected one
+                if not compare_fixit_results(test, is_standalone=False):
+                    success = False
+                    continue
+
+                if not compare_fixit_results(test, is_standalone=True):
+                    success = False
+                    continue
+
+    return success
+
 def dump_ast(check):
     for test in check.tests:
         ast_filename = test.filename() + ".ast"
         run_command(dump_ast_command(test) + " > " + ast_filename)
-        print "Dumped AST to " + os.getcwd() + "/" + ast_filename
+        print("Dumped AST to " + os.getcwd() + "/" + ast_filename)
 #-------------------------------------------------------------------------------
 def load_checks(all_check_names):
     checks = []
@@ -548,7 +726,7 @@ def load_checks(all_check_names):
             if check.enabled:
                 checks.append(check)
         except:
-            print "Error while loading " + name
+            print("Error while loading " + name)
             raise
             sys.exit(-1)
     return checks
@@ -559,24 +737,23 @@ if 'CLAZY_NO_WERROR' in os.environ:
     del os.environ['CLAZY_NO_WERROR']
 
 os.environ['CLAZY_CHECKS'] = ''
-os.environ['CLAZY_FIXIT_SUFFIX'] = '_fixed.cpp'
 
 all_check_names = get_check_names()
 all_checks = load_checks(all_check_names)
 requested_check_names = args.check_names
-requested_check_names = map(lambda x: x.strip("/\\"), requested_check_names)
+requested_check_names = list(map(lambda x: x.strip("/\\"), requested_check_names))
 
 for check_name in requested_check_names:
     if check_name not in all_check_names:
-        print "Unknown check: " + check_name
+        print("Unknown check: " + check_name)
         print
         sys.exit(-1)
 
 if not requested_check_names:
     requested_check_names = all_check_names
 
-requested_checks = filter(lambda check: check.name in requested_check_names and check.name not in _excluded_checks, all_checks)
-requested_checks = filter(lambda check: check.minimum_clang_version <= CLANG_VERSION, requested_checks)
+requested_checks = list(filter(lambda check: check.name in requested_check_names and check.name not in _excluded_checks, all_checks))
+requested_checks = list(filter(lambda check: check.minimum_clang_version <= CLANG_VERSION, requested_checks))
 
 threads = []
 
@@ -586,18 +763,17 @@ if _dump_ast:
         dump_ast(check)
         os.chdir("..")
 else:
+    cleanup_fixit_files(all_checks) # Remove stale stuff from all checks, as clang-apply-replacements will apply all .yaml files it can find, even checks that werent requested
     list_of_chunks = [[] for x in range(_num_threads)]  # Each list is a list of Test to be worked on by a thread
     i = _num_threads
     for check in requested_checks:
         for test in check.tests:
-            if not test.isFixedFile:
-                i = (i + 1) % _num_threads
-
+            i = (i + 1) % _num_threads
             list_of_chunks[i].append(test)
 
     for tests in list_of_chunks:
         if not tests:
-            continue;
+            continue
 
         t = Thread(target=run_unit_tests, args=(tests,))
         t.start()
@@ -606,9 +782,12 @@ else:
 for thread in threads:
     thread.join()
 
+if not _no_fixits and not run_fixit_tests(requested_checks):
+    _was_successful = False
+
 if _was_successful:
-    print "SUCCESS"
+    print("SUCCESS")
     sys.exit(0)
 else:
-    print "FAIL"
+    print("FAIL")
     sys.exit(-1)
